# -*- coding: utf-8 -*-

#==============================================================================
#测试方法：先卸载siat：pip uninstall siat
import os; os.chdir('S:/siat')
from siat import *

#第一步：查询金融期权期权
#查看中国当前的金融期权品种
option_fin_china()

#如果希望查看更多内容：
option_fin_china(detail=True)

#查看某个金融期权品种的到期月份：以华夏上证50ETF期权为例
option="华夏上证50ETF期权"
option_fin_month_china(option)

#查看某个金融期权在某个到期月份的具体合约：以华夏上证50ETF期权2022年6月到期的看涨合约为例
end_month='2206'
direction='call'
#脚本默认是看涨期权合约
contracts=option_fin_contracts(option,end_month,direction)

#如果希望查看看跌期权合约
contracts=option_fin_contracts(option,end_month,'put')

#如果希望查看看涨和看跌期权的全部合约：发现看涨和看跌合约都是配对出现的
contracts=option_fin_contracts(option,end_month,'both')

#第二步：查找计算金融期权预期价格所需要的参数
#以2022年6月份到期的华夏上证50ETF期权合约510050C2206M02900为例
contract='510050C2206M02900'
ua,maturity,x=option_fin_contract_parms(option,end_month,contract,direction)
print("underlying asset is",ua)
print("maturity date is",maturity)
print("strike price is",x)
#其到期日是2022-6-28

#计算期权标的证券（510050.SS）价格的历史波动率：
#假定今日是2021-11-19，使用历史样本的期间长度为日历日180天(可更改)
today='2021-11-19'
hist_sample_len=180
sigma,s0,_=underlying_sigma(ua,today,days=hist_sample_len)
print("annualized_sigma is",round(sigma,5))    
print("underlying security price is",s0)    

#查找年化无风险利率：基于SHIBOR三个月期利率(3M)，默认是近30天内的最新利率
rate_period='3M'
rf=shibor_rate(today,rate_period) 
print("risk-free interest rate is",rf)

#如果未找到，可以扩大查找范围，例如扩大到近期60天内的最新利率
daysahead=60
rf=shibor_rate(today,rate_period,daysahead)

#计算当前日期距离合约到期日的天数
days,_=calc_days(today,maturity)
print("days is",days)    

#第三步：计算期权合约的预期价格
#中国目前金融期权均为无红利的欧式期权，可以直接采用Black-Scholes期权定价模型
expected_price=bs_pricing(s0,x,days,rf,sigma,direction)
#计算的预期结果：0.44，实际价格0.4411
#==============================================================================
#==============================================================================
from siat import *

#第一步：查询金融期权期权
#查看中国当前的金融期权品种
option_fin_china()

#如果希望查看更多内容：
option_fin_china(detail=True)

#查看某个金融期权品种的到期月份：以上交所沪深30050ETF期权（即华泰柏瑞沪深300ETF期权）为例
option="华泰柏瑞沪深300ETF期权"
option_fin_month_china(option)

#查看某个金融期权在某个到期月份的具体合约：
#以华泰柏瑞沪深300ETF期权2022年6月到期的看涨合约为例
end_month='2206'
direction='call'
#脚本默认是看涨期权合约
contracts=option_fin_contracts(option,end_month,direction)

#如果希望查看看跌期权合约
contracts=option_fin_contracts(option,end_month,'put')

#如果希望查看看涨和看跌期权的全部合约：发现看涨和看跌合约都是配对出现的
contracts=option_fin_contracts(option,end_month,'both')

#第二步：查找计算金融期权预期价格所需要的参数
#以2022年6月份到期的华夏上证50ETF期权合约510300C2206M04500为例
contract='510300C2206M04500'
ua,maturity,x=option_fin_contract_parms(option,end_month,contract,direction)
print("underlying asset is",ua)
print("maturity date is",maturity)
print("strike price is",x)
#其到期日是2022-6-28

#计算期权标的证券（510050.SS）价格的历史波动率：
#假定今日是2021-11-19，使用历史样本的期间长度为日历日30天(可更改）
today='2021-11-19'
hist_sample_len=30
sigma,s0,_=underlying_sigma(ua,today,days=hist_sample_len)
print("annualized_sigma is",round(sigma,5))    
print("underlying security price is",s0)    

#查找年化无风险利率：基于SHIBOR三个月期利率(3M)，默认是近30天内的最新利率
rate_period='3M'
rf=shibor_rate(today,rate_period) 
print("risk-free interest rate is",rf)

#如果未找到，可以扩大查找范围，例如扩大到近期60天内的最新利率
daysahead=60
rf=shibor_rate(today,rate_period,daysahead)

#计算当前日期距离合约到期日的天数
days,_=calc_days(today,maturity)
print("days is",days)

#第三步：计算期权合约的预期价格
#中国目前金融期权均为无红利的欧式期权，可以直接采用Black-Scholes期权定价模型
expected_price=bs_pricing(s0,x,days,rf,sigma,direction)
#计算的预期结果：0.55，实际价格0.51
#==============================================================================


# 绝对引用指定目录中的模块
import sys
sys.path.insert(0,r'S:\siat\siat')
from option_china import *
#==============================================================================
def option_fin_china():
    """
    查找中国金融期权列表
    """
    option_fin_list=['华夏上证50ETF期权','华泰柏瑞沪深300ETF期权', \
                     '嘉实沪深300ETF期权','沪深300股指期权']
    num=len(option_fin_list)

    print("  There are",num,"financial options in China mainland at present:")
    for i in option_fin_list:
        print(' ',i)
        
    return option_fin_list



import akshare as ak
#横截面数据
df1 = ak.option_finance_board(symbol="华夏上证50ETF期权", end_month="2112")
list(df1)
#['合约交易代码', '当前价', '涨跌幅', '前结价', '行权价', '数量']

df2 = ak.option_finance_board(symbol="嘉实沪深300ETF期权", end_month="2112")
list(df2)
['合约编码', '合约简称', '标的名称', '类型', '行权价', '合约单位', '期权行权日', '行权交收日']

df3 = ak.option_finance_board(symbol="华泰柏瑞沪深300ETF期权", end_month="2112")
list(df3)
#['合约交易代码', '当前价', '涨跌幅', '前结价', '行权价', '数量']

df4 = ak.option_finance_board(symbol="沪深300股指期权", end_month="2112")
list(df4)
#['instrument',
 'position',
 'volume',
 'lastprice',
 'updown',
 'bprice',
 'bamount',
 'sprice',
 'samount']








#沪深300指数期权
df10 = ak.option_sina_cffex_hs300_list()
#实时行情
df11 = ak.option_sina_cffex_hs300_spot(contract="io2112")
df12 = ak.option_sina_cffex_hs300_daily(contract="io2004C4450")

#==============================================================================
#查找中国商品期权的常见品种
df1=option_comm_china()

#查找中国黄金期权的可用合约
df2=option_comm_china('黄金')

#查找中国黄金期权au2112和au2202的具体合约（看涨/看跌合约）
df3=option_comm_china('黄金','au2112')
df3b=option_comm_china('黄金','au2202')
#同一时刻行权价对期权合约的影响：行权价越高，看涨期权合约价格越低，看跌期权合约价越高

#单一期权合约价格的运动趋势：默认不带趋势线
df4=option_comm_trend_china('au2202C364','2021-9-1','2021-9-30',power=4)

#期权方向对合约价格走势的影响：看涨/看跌期权合约的价格走势正好相反
df5=option_comm_trend_china(['au2202C364','au2202P364'],'2021-8-1','2021-9-30')

#行权价对合约价格时间序列走势的影响：看涨期权，行权价低者合约价高
df6=option_comm_trend_china(['au2112C328','au2112C364'],'2021-8-1','2021-9-30')
#行权价对合约价格时间序列走势的影响：看跌期权，行权价低者合约价低，与看涨期权正好相反
df6b=option_comm_trend_china(['au2112P328','au2112P364'],'2021-8-1','2021-9-30')

#到期时间对合约价格走势的影响：看涨期权，到期日近者合约价低（时间价值少）
df7=option_comm_trend_china(['au2112C364','au2202C364'],'2021-8-1','2021-9-30')
#到期时间对合约价格走势的影响：看跌期权，到期日近者合约价低，与看涨期权一致
df7b=option_comm_trend_china(['au2112P364','au2202P364'],'2021-8-1','2021-9-30')



#==============================================================================

import os; os.chdir('S:/siat')
from siat import *

import warnings

with warnings.catch_warnings():
    warnings.simplefilter('ignore')
    lg = bs.login()

disable_prints()











